/*
 * Copyright  2013 Nokia Corporation. All rights reserved.
 * Nokia and Nokia Connecting People are registered trademarks of Nokia Corporation. 
 * Oracle and Java are trademarks or registered trademarks of Oracle and/or its
 * affiliates. Other product and company names mentioned herein may be trademarks
 * or trade names of their respective owners. 
 * See LICENSE.TXT for license information.
 */ 
package com.nokia.example.bcexchanger.comm;

/**
 * 
 * This interface contains the methods which the states of the
 * communication state machine use to get needed functionality from
 * the parent
 * 
 * This interface is implemented by ExchangerCommImpl class.
 * 
 */
public interface ExchangerStateParent {

    /**
     * Current state setter
     * <p>
     * Sets the current state in the parent
     * 
     * @param state -
     *          state of communication machine
     */
    public void setState(ExchangerState state);

    /**
     * Listener getter
     * <p>
     * Returns the communication event listener which is stored in the
     * parent
     * 
     * @return communication event listener interface
     */
    public ExchangeListener getListener();

    /**
     * Communication state getter
     * <p>
     * Returns current state of the communication machine which is kept
     * in the parent
     * 
     * @return current state of the communication machine
     */
    public ExchangerState getState();

    /**
     * Returns "Business Card Exchanger Service" UUID
     * 
     * @return string containing UUID of the Bluetooth OBEX server
     *         connection
     */
    public String getUUID();
}
